@@ -254,6 +254,8 @@ public class QtTextToSpeech
     {
         //Log.d("QtTextToSpeech", "getLocale: " + mLocale);
         final Locale language = mTts.getLanguage();
+        if (language == null)
+            return null;
         String languageCode = language.getLanguage();
         String countryCode = language.getCountry();
 
